scxpand.data\_util.data\_splitter
=================================

.. automodule:: scxpand.data_util.data_splitter

   
   .. rubric:: Functions

   .. autosummary::
   
      calculate_and_log_cancer_distribution
      calculate_and_log_category_distributions
      get_patient_identifiers
      log_dataset_overview
      log_split_results
      save_patient_ids
      split_data
      validate_patient_cancer_types
   